@@ -12,7 +12,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ==============================================================================*/
-#include "tree/tree.h"
+#include "tree.h"
 
 #include <memory>
 #include <string>
@@ -22,7 +22,7 @@ limitations under the License.
 #include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
-#include "pybind11/pybind11.h"
+#include <pybind11/pybind11.h>
 
 #ifdef LOG
 #define LOG_WARNING(w) LOG(WARNING) << w;
@@ -40,10 +40,6 @@ namespace py = pybind11;
 namespace tree {
 namespace {
 
-struct DecrementsPyRefcount {
-  void operator()(PyObject* p) const { Py_DECREF(p); }
-};
-
 // PyObjectPtr wraps an underlying Python object and decrements the
 // reference count in the destructor.
 //
@@ -178,8 +174,8 @@ py::object GetWraptObjectProxyTypeUncached() {
 }
 
 py::object GetWraptObjectProxyType() {
-  static py::object type = GetWraptObjectProxyTypeUncached();
-  return type;
+  // TODO(gregthornton): Restore caching when deadlock issue is fixed.
+  return GetWraptObjectProxyTypeUncached();
 }
 
 // Returns 1 if `o` is considered a mapping for the purposes of Flatten().
@@ -256,21 +252,6 @@ int IsSequenceHelper(PyObject* o) {
   return check_cache->CachedLookup(o);
 }
 
-// ValueIterator interface
-class ValueIterator {
- public:
-  virtual ~ValueIterator() {}
-  virtual PyObjectPtr next() = 0;
-
-  bool valid() const { return is_valid_; }
-
- protected:
-  void invalidate() { is_valid_ = false; }
-
- private:
-  bool is_valid_ = true;
-};
-
 using ValueIteratorPtr = std::unique_ptr<ValueIterator>;
 
 // Iterate through dictionaries in a deterministic order by sorting the
@@ -407,17 +388,6 @@ class AttrsValueIterator : public ValueIterator {
   PyObjectPtr iter_;
 };
 
-ValueIteratorPtr GetValueIterator(PyObject* nested) {
-  if (PyDict_Check(nested)) {
-    return absl::make_unique<DictValueIterator>(nested);
-  } else if (IsMappingHelper(nested)) {
-    return absl::make_unique<MappingValueIterator>(nested);
-  } else if (IsAttrsHelper(nested)) {
-    return absl::make_unique<AttrsValueIterator>(nested);
-  } else {
-    return absl::make_unique<SequenceValueIterator>(nested);
-  }
-}
 
 bool FlattenHelper(
     PyObject* nested, PyObject* list,
@@ -749,6 +719,18 @@ void AssertSameStructure(PyObject* o1, PyObject* o2, bool check_types) {
   }
 }
 
+ValueIteratorPtr GetValueIterator(PyObject* nested) {
+  if (PyDict_Check(nested)) {
+    return absl::make_unique<DictValueIterator>(nested);
+  } else if (IsMappingHelper(nested)) {
+    return absl::make_unique<MappingValueIterator>(nested);
+  } else if (IsAttrsHelper(nested)) {
+    return absl::make_unique<AttrsValueIterator>(nested);
+  } else {
+    return absl::make_unique<SequenceValueIterator>(nested);
+  }
+}
+
 namespace {
 
 inline py::object pyo_or_throw(PyObject* ptr) {
